package com.capitalware.mqcm.models;

import java.util.ArrayList;
import java.util.ResourceBundle;

import javax.swing.table.AbstractTableModel;

/**
 * This class is the model ("M") of the MVC.
 * It will handle the setting and getting of the data to and from the table.
 *
 * @author Roger Lacroix
 * @version 1.2
 * @license Apache 2 License
 */
public class MQChannelStatusModel extends AbstractTableModel
{
   private String columnNames[] = new String[16];
   private ArrayList<Object> tableData;

   /**
    * The constructor
    * @param al
    * @param labels
    */
   public MQChannelStatusModel(ArrayList<Object> al, ResourceBundle labels)
   {
      super();
      tableData = al;
      
      columnNames[0]  = labels.getString("table.column.header.channelname");
      columnNames[1]  = labels.getString("table.column.header.connectionname");
      columnNames[2]  = labels.getString("table.column.header.status");
      columnNames[3]  = labels.getString("table.column.header.substate");
      columnNames[4]  = labels.getString("table.column.header.messages");
      columnNames[5]  = labels.getString("table.column.header.lastmsgdate");
      columnNames[6]  = labels.getString("table.column.header.lastmsgtime");
      columnNames[7]  = labels.getString("table.column.header.bytessent");
      columnNames[8]  = labels.getString("table.column.header.bytesreceived");
      columnNames[9]  = labels.getString("table.column.header.bufferssent");
      columnNames[10] = labels.getString("table.column.header.buffersreceived");
      columnNames[11] = labels.getString("table.column.header.startdate");
      columnNames[12] = labels.getString("table.column.header.starttime");
      columnNames[13] = labels.getString("table.column.header.mcastatus");
      columnNames[14] = labels.getString("table.column.header.mcauserid");
      columnNames[15] = labels.getString("table.column.header.mcajobname");
   }

   /**
    * Retrieve the number of rows in the table.
    * @return rowCount
    */
   public int getRowCount()
   {
      return tableData.size();
   }

   /**
    * Retrieve the number of columns in the table.
    * @return columnCount
    */
   public int getColumnCount()
   {
      return columnNames.length;
   }

   /**
    * Retrieve a value of a particular cell.
    * @param i
    * @param j
    * @return object
    */
   public Object getValueAt(int i, int j)
   {
      if (i > tableData.size())
         return null;
      if (j > columnNames.length)
         return null;

      Object[] rowCells =  (Object[])tableData.get(i);

      return  rowCells[j];
   }

   /**
    * Retrieve the data for an entire row.
    * @param r
    * @return objectArray
    */
   public Object[] getRowData(int r)
   {
      if (r < tableData.size())
         return ((Object[]) tableData.get(r));
      else
         return null;
   }

   /**
    * Retrieve the name of a column..
    * @param i
    * @return columnName
    */
   public String getColumnName(int i)
   {
      return columnNames[i];
   }

   /**
    * Replace the entire table data
    * @param al
    */
   public void setTableData(ArrayList<Object> al)
   {
      ArrayList<Object> old_al = this.tableData;
      this.tableData = al;
      /*
       * Help GC notice that the old objects are no longer used.
       */
      old_al.clear();
      old_al = null;
   }
}
