package com.capitalware.mqcm.renderers;

import java.awt.Color;
import java.awt.Component;
import java.util.ResourceBundle;

import javax.swing.JTable;
import javax.swing.SwingConstants;
import javax.swing.table.DefaultTableCellRenderer;

/**
 * Table cell renderer to highlight certain channel status values.
 *
 * @author Roger Lacroix
 * @version 1.2
 * @license Apache 2 License
 */
public class RenderRedYellow extends DefaultTableCellRenderer
{
   private String stopped = null;
   private String stopping = null;
   private String running = null;
   private String inactive = null;

   /**
    * The constructor
    * @param labels
    */
   public RenderRedYellow(ResourceBundle labels)
   {
      super();

      stopped  = labels.getString("table.chl.status.stopped");
      stopping = labels.getString("table.chl.status.stopping");
      running  = labels.getString("table.chl.status.running");
      inactive = labels.getString("table.chl.status.inactive");
      
      setHorizontalAlignment(SwingConstants.CENTER);
   }

   /**
    * Override this method
    */
   public Component getTableCellRendererComponent(JTable table,
                                                  Object value,
                                                  boolean isSelected,
                                                  boolean hasFocus,
                                                  int row,
                                                  int column)
   {
      super.getTableCellRendererComponent(table,value,isSelected,hasFocus,row,column);

      if (value == null)
         return this;

      Color backGround = getBackground();

      if ( (column == 2) || (column == 13) )
      {
         if (value instanceof String)
         {
            if ( ((String) value).equals(stopped)  ||
                 ((String) value).equals(stopping) )
            {
               setForeground(isSelected ? Color.red   : Color.white);
               setBackground(isSelected ? backGround  : Color.red);
            }
            else if ( (((String) value).equals(running))  ||
                      (((String) value).equals(inactive)) )
            {
               setForeground(isSelected ? Color.white : Color.black);
               setBackground(isSelected ? backGround  : Color.white);
            }
            else
            {
               setForeground(isSelected ? Color.yellow : Color.black);
               setBackground(isSelected ? backGround   : Color.yellow);
            }
         }
         else
         {
            setForeground(isSelected ? Color.white : Color.black);
            setBackground(isSelected ? backGround  : Color.white);
         }
      }
      else
      {
         setForeground(isSelected ? Color.white : Color.black);
         setBackground(isSelected ? backGround  : Color.white);
      }
      
      return this;
   }
}
